==> rtu34_1.8.4.tar.gz: rtu34/man/rtu34PMID.Rd <==
\name{rtu34PMID}
\alias{rtu34PMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   rtu34PMID is an R environment that provides mappings between
   manufacturer ids and PubMed ids.
}
\details{
  Each manufacturer id is mapped to a named vector of PubMed ids. The
  name associated with each vector corresponds to the manufacturer
  id. The length of the vector may be one or greater, depending on how
  many PubMed ids a given manufacturer id is mapped to. An \code{NA} is
  reported for any manufacturer id that cannot be mapped to a PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 18:20:58 2005

  Package built Tue May 17 18:23:17 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(rtu34PMID)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}

==> rtu34_1.10.0.tar.gz: rtu34/man/rtu34PMID.Rd <==
\name{rtu34PMID}
\alias{rtu34PMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   rtu34PMID is an R environment that provides mappings between
   manufacturer ids and PubMed ids.
}
\details{
  Each manufacturer id is mapped to a named vector of PubMed ids. The
  name associated with each vector corresponds to the manufacturer
  id. The length of the vector may be one or greater, depending on how
  many PubMed ids a given manufacturer id is mapped to. An \code{NA} is
  reported for any manufacturer id that cannot be mapped to a PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 20:15:19 2005

  Package built Tue Oct  4 20:23:13 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(rtu34PMID)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}
